<?php

require_once dirname( __FILE__ ) . '/mediabox-strings.php';

class Kite_Theme_Admin {

	/**
     * Instance of this class.
     *
     * @var      object
     */
	protected static $instance = null;
	

	function __construct() {
		add_action( 'admin_init', array( &$this, 'kite_admin_init' ) );
		add_action( 'after_setup_theme', array( &$this, 'kite_after_setup' ) );
		add_action( 'switch_theme', array( &$this, 'kite_after_deactivate' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'init_admin_scripts' ), 200 ); // add high priority to print them at the end of page (specially admin.js)
	}

	function init_admin_scripts() {
		
		// Enqueue Styles
		$icomoon_handler = wp_style_is( 'icomoon', 'queue' ) ? 'kite-icomoon' : 'icomoon';
		wp_enqueue_style( $icomoon_handler, KITE_THEME_ASSETS_URI . '/css/icomoon.css', false, KITE_THEME_VERSION );
		wp_enqueue_style( 'kite-admin-css', KITE_THEME_LIB_URI . '/admin/css/style.css', false, '1.0.0', 'screen' );

		// Enqueue Scripts
		$screen = get_current_screen();
		if ( $screen->base == 'post' || $screen->base == 'edit-tags' || $screen->base == 'term' || $screen->base == "widgets" ) {
			wp_enqueue_script( 'sweet-alert', KITE_THEME_LIB_URI . '/admin/scripts/sweet-alert.min.js', array( 'jquery' ), '0.4.1' );
		}

		wp_enqueue_script( 'kite-admin-js', KITE_THEME_LIB_URI . '/admin/scripts/admin.js', array( 'jquery' ), '1.0.0' );
		wp_localize_script( 
			'kite-admin-js', 
			'kite_theme_admin_vars', 
			array(
				'ajax_url'         	=> esc_url( admin_url( 'admin-ajax.php' ) ),
				'wpnonce' 			=> wp_create_nonce( 'kite_theme_admin_nonce' ),
				'select_plugins'	=> __( 'Please select Plugins you want to install', 'pinkmart' )
			) 
		);

	}

	function kite_after_deactivate() {
		update_option( 'theme_initialised', false );

	}

	function kite_after_setup() {
		// Use an option to run this function just 1 time and after theme activation
		// we can't use directly after_switch_theme hook because we need activated plguins before that
		if ( ! is_admin() ) {
			return;
		}

		$theme_initialised = get_option( 'theme_initialised' );

		if ( $theme_initialised != true ) {
			if ( ! get_option( 'theme_' . KITE_THEME_SLUG . '_default_options', false ) ) {
				$theme_default_options = array(
					'page_breadcrumb'                      => true,
					'scrolling-easing'                     => 'easeInOutQuart',
					'scrolling-speed'                      => 1000,
					'retina_ready'                         => 0,
					'portfolio_gallery_images'             => 0,
					'container_size'                       => true,
					'dynamic_container_size'               => 1200,
					'style-accent-color'                   => array(
						'color' => '#ff4c2f',
						'alpha' => '1',
					),
					'style-highlight-color'                => array(
						'color' => '#424242',
						'alpha' => '1',
					),
					'style-link-color'                     => array(
						'color' => '#ff4c2f',
						'alpha' => '1',
					),
					'style-link-hover-color'               => array(
						'color' => '#424242',
						'alpha' => '1',
					),
					'element-on-accent-color-style'        => true,
					'loader_display'                       => false,
					'page-transition-type'                 => 'none',
					'preloader_display'                    => true,
					'preloader-type'                       => 'simple',
					'preloader_color'                      => array(
						'color' => '#c7c7c7',
						'alpha' => '1',
					),
					'preloader_bg_color'                   => array(
						'color' => '#efefef',
						'alpha' => '1',
					),
					'preloader_box_color'                  => array(
						'color' => '#f7f7f7',
						'alpha' => '1',
					),
					'preloader_text_color'                 => array(
						'color' => '#000',
						'alpha' => '1',
					),
					'popupNewsletterDisplay'               => false,
					'popupNewsLetterDisplayMobile'         => false,
					'popupNewsLetterDelay'                 => 1000,
					'Header_PromoBar_Display'              => false,
					'Header_PromoBar_textcolor'            => 'light',
					'Header_PromoBar_height'               => 50,
					'Header_PromoBar_mobileheight'         => 60,
					'Header_PromoBar_BgColor'              => array(
						'color' => '#000000',
						'alpha' => '1',
					),
					'Header_PromoBar_closebtn'             => true,
					'topbar_display'                       => false,
					'boxed_topbar'                         => false,
					'topbar_bg_color'                      => array(
						'color' => '#eee',
						'alpha' => '1',
					),
					'topbar_border_color'                  => array(
						'color' => '#eee',
						'alpha' => '1',
					),
					'topbar_style'                         => false,
					'topbar-compare-display'               => true,
					'topbar-social-display'                => true,
					'topbar_currency_shortcode'            => '[woocs show_flags=0 flag_position="left"]',
					'shop-login-link'                      => true,
					'header-type'                          => 4,
					'menu-container'                       => false,
					'searchbox-style'                      => false,
					'header-style'                         => 'normal-menu',
					'responsive-second-state'              => false,
					'cat-menu-state-open'                  => false,
					'cat-menu-state-light'                 => false,
					'menu-hover-style'                     => 3,
					'initial-menu-background-color'        => array(
						'color' => '#ffffff',
						'alpha' => '1',
					),
					'initial-menu-text-color'              => array(
						'color' => '#000000',
						'alpha' => '1',
					),
					'initial-menu-text-hover-color'        => array(
						'color' => '#000000',
						'alpha' => '1',
					),
					'initial-menu-text-bg-hover-color'     => array(
						'color' => '#f83333',
						'alpha' => '1',
					),
					'initial-menu-border-color'            => array(
						'color' => 'rgba(255,255,255,0)',
						'alpha' => '0',
					),
					'menu-background-color'                => array(
						'color' => '#ffffff',
						'alpha' => '1',
					),
					'menu-text-color'                      => array(
						'color' => '#000000',
						'alpha' => '1',
					),
					'menu-text-hover-color'                => array(
						'color' => '#000000',
						'alpha' => '1',
					),
					'menu-text-bg-hover-color'             => array(
						'color' => '#e8e8e8',
						'alpha' => '1',
					),
					'menu-border-color'                    => array(
						'color' => '#eee',
						'alpha' => '0',
					),
					'menu-opacity'                         => 30,
					'mobile_menu-color'                    => true,
					'submenu-hover-style'                  => 0,
					'submenu-background-color'             => array(
						'color' => '#fff',
						'alpha' => '1',
					),
					'submenu-text-color'                   => array(
						'color' => '#222',
						'alpha' => '1',
					),
					'submenu-heading-color'                => array(
						'color' => '#111',
						'alpha' => '1',
					),
					'vertical_menu_copyright'              => '&copy; 2019 KiteStudio | Built With The ' . KITE_THEME_NAME . ' Theme',
					'font-navigation-type'                 => 'default',
					'menu-search'                          => true,
					'search_post_type'                     => 'product',
					'shop-enable-cart'                     => true,
					'icon_type'                            => 'cart',
					'header-wishlist-display'              => true,
					'responsive-wishlist-display'          => false,
					'shop-wishlist-cart-style'             => true,
					'shop-wishlist-cart-bg-color'          => array(
						'color' => '#eee',
						'alpha' => '1',
					),
					'font-body-type'                       => 'default',
					'font-headings-type'                   => 'default',
					'sidebar-position'                     => 2,
					'blog-sidebar-position'                => 'main-sidebar',
					'search-widget-category'               => false,
					'shop-column'                          => 4,
					'shop-column-tablet'               	   => '3',
					'shop-column-responsive'               => '1',
					'shop-item-per-page'                   => '12',
					'products-pagination'                  => 'pagination',
					'ajax_shop_pagination'                 => true,
					'shop-product-view'                    => 'grid',
					'shop-layout'                          => 'fitRows',
					'shop-product-style'                   => 'buttonsonhover',
					'product-hover-color'                  => 'c0392b',
					'product-hover-custom-color'           => array(
						'color' => '#fff',
						'alpha' => '1',
					),
					'shop-product-color-scheme'            => true,
					'shop-product-gutter'                  => true,
					'shop-product-border'                  => true,
					'shop-product-rating'                  => false,
					'shop-entrance-animation'              => 'fadein',
					'shop-enable-fullwidth'                => false,
					'shop-sidebar-position'                => 0,
					'recently_viewed_product'              => true,
					'recently_viewed_product_display'      => true,
					'recently_viewed_product_responsive'   => false,
					'shop-filter'                          => false,
					'shop-filter-style'                    => true,
					'shop-filter-categories'               => true,
					'shop_filter_hidden_empty_category'    => false,
					'shop-filter-sorting'                  => true,
					'product-per-page'                     => true,
					'shop-filter-active-filters'           => true,
					'shop-filter-search'                   => true,
					'catalog_mode'                         => false,
					'catalog_mode_price'                   => false,
					'shop-enable-quickview'                => true,
					'shop-enable-fixed-addtocart'          => true,
					'product-hover-image'                  => true,
					'category-description-position'        => true,
					'woocommerce-notices'                  => true,
					'percentage_sale'                      => true,
					'rating_in_woocommerce_product_widget' => true,
					'show_more_button_in_woocommerce_categories_widget' => true,
					'product-detail-style'                 => 'pd_classic',
					'product-detail-sidebar-position'      => 'right',
					'product-detail-gallery-sidebar-position'      => 'right',
					'product-detail-sidebar-responsive'    => false,
					'product-detail-bg'                    => array(
						'color' => '#fff',
						'alpha' => '1',
					),
					'variable_title'                       => true,
					'variations_select_style'              => true,
					'product_description_align'            => true,
					'product_navigation'                   => true,
					'product_breadcrumb'                   => true,
					'product_wishlist_compare_style'       => true,
					'product_360_view'                     => false,
					'product_gallery_popup'                => false,
					'product_gallery_style'                => false,
					'product_gallery_autoplay'             => true,
					'related_product'                      => true,
					'related_product_display'              => true,
					'related_product_width'                => false,
					'cookies_info'                         => false,
					'footer-widget-area'                   => false,
					'footer_widgets'                       => 0,
					'product_widget_area'                  => false,
					'category_widget_area'                 => false,
					'footer-widget-gradianet'              => false,
					'footer-widget-color'                  => array(
						'color' => '#f5f5f5',
						'alpha' => '1',
					),
					'footer-widget-style'                  => false,
					'footer-widget_width'                  => false,
					'footerType'                           => 'logo-in-middle',
					'footer-copyright'                     => '&copy; 2019 KiteStudio | Built With The ' . KITE_THEME_NAME . ' Theme',
					'footerStyle'                          => false,
					'footerFullwidth'                      => false,
					'rss_url'                              => false,
					'social_share_display'                 => false,
					'social_share_facebook'                => false,
					'social_share_mail'                    => false,
					'social_share_twitter'                 => false,
					'social_share_telegram'               => false,
					'social_share_whatsapp'               => false,
					'social_share_linkedin'               => false,
					'social_share_vk'               => false,
					'social_share_pinterest'               => false,
					'social_network_display'               => false,
					'maintenance_mode'                     => true,
				);
				update_option( 'theme_' . KITE_THEME_SLUG . '_default_options', maybe_serialize( $theme_default_options ) );
			}
			if ( class_exists( 'WPBakeryVisualComposerAbstract' ) || class_exists( 'YITH_WCWL' ) ) {
				update_option( 'theme_initialised', true );
			}

			if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {

				// Enable Visual composer in portfolio,page,post and product
				$pt_array = vc_editor_post_types();

				if ( is_array( $pt_array ) ) {

					if ( ! in_array( 'post', $pt_array ) ) {
						$pt_array[] = 'post';
					}

					if ( ! in_array( 'portfolio', $pt_array ) ) {
						$pt_array[] = 'portfolio';
					}

					if ( ! in_array( 'page', $pt_array ) ) {
						$pt_array[] = 'page';
					}

					if ( ! in_array( 'product', $pt_array ) ) {
						$pt_array[] = 'product';
					}

					vc_editor_set_post_types( $pt_array );
				}
			}

			// Set wishlist position after add to cart button
			if ( class_exists( 'YITH_WCWL' ) ) {

				$wishlist_position = get_option( 'yith_wcwl_button_position' );

				if ( $wishlist_position != 'add-to-cart' ) {
					update_option( 'yith_wcwl_button_position', 'add-to-cart' );
				}
			}
		}
	}
	function kite_activation() {
		// Redirect To Theme Options Page on Activation
		if ( isset( $_GET['activated'] ) ) {
			if ( get_option( 'theme_setup_complete', false ) ) {
				return;
			}
			wp_redirect( admin_url( 'admin.php?page=' . KITE_THEME_SLUG . '-setup' ) );
			if ( is_child_theme() ) {
				wp_redirect( admin_url( 'admin.php?page=' . KITE_THEME_SLUG . 'child-setup' ) );
			}
		}
	}
	function kite_admin_init() {
		if ( in_array( $GLOBALS['pagenow'], array( 'media-upload.php', 'async-upload.php' ) ) ) {
			// Now we'll replace the 'Insert into Post Button' inside Thickbox
			add_filter( 'gettext', array( &$this, 'kite_replace_thickbox_text' ), 1, 3 );
		}

		// check if our old kt-core plugin or pinkmart shortcode plugin is active, then deactivate them
		if ( function_exists( 'activate_Kite_core' ) ) {
			deactivate_plugins( 'kt-core/kt-core.php',false, null );
		}

		if ( function_exists( 'activate_Kite_shortcodes' ) ) {
			deactivate_plugins( 'kt-shortcodes/kt-shortcodes.php',false, null );
		}
	}

	function kite_replace_thickbox_text( $translated_text, $text, $domain ) {
		if ( 'Insert into Post' == $text ) {

			$texts = kite_get_media_box_strings();

			foreach ( $texts as $key => $value ) {
				$referer = strpos( wp_get_referer(), $key );

				if ( $referer !== false ) {
					return $value;
				}
			}
		}

		return $translated_text;
	}

	/**
     * Return an instance of this class.
     *
     * @return    object    A single instance of this class.
     */
    public static function get_instance() {

        // If the single instance hasn't been set, set it now.
        if ( null == self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
    }
}
Kite_Theme_Admin::get_instance();
