<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Kite_Gallery' ) ) {
	class Kite_Gallery extends Kite_Post_Type {

		/**
		 * Instance of this class.
		 *
		 * @var      object
		 */
		protected static $instance = null;
	
		/**
		 * Return an instance of this class.
		 *
		 * @return    object    A single instance of this class.
		 */
		public static function get_instance() {
	
			// If the single instance hasn't been set, set it now.
			if ( null == self::$instance ) {
				self::$instance = new self;
			}
	
			return self::$instance;
		}
	
		function __construct() {
			parent::__construct( 'gallery' );
		}
	
		function kite_enqueue_scripts() {
			wp_enqueue_script( 'hoverIntent' );
			wp_enqueue_script( 'jquery-easing' );
	
			wp_enqueue_script( 'nouislider' );
			wp_enqueue_style( 'nouislider' );
	
			// Include wpcolorpicker + its patch to support alpha chanel
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker-alpha' );
	
			wp_enqueue_style( 'kite-admin-css' );
			wp_enqueue_script( 'kite-admin-js' );
	
			wp_enqueue_script( 'kite-portfolio', KITE_THEME_LIB_URI . '/post-types/js/portfolio.js', array( 'jquery' ), KITE_THEME_VERSION );
	
		}
	
		protected function kite_get_options() {
			$fields = array(
				'title-bar-switch'           => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Section Title', 'pinkmart' ),
					'options' => array(
						'2' => esc_html__( 'Show gallery item title', 'pinkmart' ),
						'1' => esc_html__( 'Show custom title', 'pinkmart' ),
					),
				),
				'title-text'                 => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Title Text', 'pinkmart' ),
					'placeholder' => esc_html__( 'Override title text', 'pinkmart' ),
	
				),
				'subtitle-text'              => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Subtitle Text', 'pinkmart' ),
					'placeholder' => esc_html__( 'Subtitle text', 'pinkmart' ),
				),
	
				'image'                      => array(
					'type'    => 'upload',
					'title'   => esc_html__( 'Gallery Image', 'pinkmart' ),
					'referer' => 'kt-portfolio-image',
					'meta'    => array( 'array' => true ),
				),
				'video-type'                 => array(
					'type'    => 'select',
					'options' => array(
						'vimeo'   => esc_html__( 'Vimeo', 'pinkmart' ),
						'youtube' => esc_html__( 'YouTube', 'pinkmart' ),
					),
				),
				'video-id'                   => array(
					'type'        => 'text',
					'placeholder' => esc_html__( 'Video URL', 'pinkmart' ),
				), // video id
				'audio-url'                  => array(
					'type'        => 'text',
					'placeholder' => esc_html__( 'Audio URL', 'pinkmart' ),
				), // Audio URL
				'link-url'                   => array(
					'type'        => 'text',
					'placeholder' => esc_html__( 'URL', 'pinkmart' ),
				), // link
				'portfolio-featured-size'    => array(
					'type'    => 'visual-select',
					'title'   => 'Choose your gallery post size',
					'options' => array(
						'square' => 'square',
						'big'    => 'big',
						'slim'   => 'slim',
						'hslim'  => 'hslim',
						'wide'   => 'wide',
					),
				),
				'gallery-external-link'      => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Button URL', 'pinkmart' ),
					'placeholder' => esc_html__( 'ADD button URL Here', 'pinkmart' ),
				), // gallery external link URL
				'gallery-external-link-text' => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Button Text', 'pinkmart' ),
					'placeholder' => esc_html__( 'ADD button text here', 'pinkmart' ),
				), // gallery external link text
				'attribute-value'            => array(
					'type'        => 'text',
					'class'       => 'attribute-value',
					'placeholder' => esc_html__( 'Attribute Value', 'pinkmart' ),
					'meta'        => array(
						'array'    => true,
						'dontsave' => true,
					), // This will indirectly get saved
				), // Attribute Value
			);
	
			// Option sections
			$options = array(
				'title-bar'             => array(
					'title'   => esc_html__( 'Gallery Item Title', 'pinkmart' ),
					'tooltip' => esc_html__( 'Enter a gallery item title.', 'pinkmart' ),
					'fields'  => array(
						'title-bar'     => $fields['title-bar-switch'],
						'title-text'    => $fields['title-text'],
						'subtitle-text' => $fields['subtitle-text'],
					),
				), // Title bar sec
				'gallery-external-link' => array(
					'title'   => esc_html__( 'Add URL and text for The button that appears on the image pop-up', 'pinkmart' ),
					'tooltip' => esc_html__( 'Add URL and text for The button that appears on the image pop-up, ', 'pinkmart' ),
					'fields'  => array(
						'gallery-external-link'      => $fields['gallery-external-link'],
						'gallery-external-link-text' => $fields['gallery-external-link-text'],
					),
				), // look book Button
				'featured-size'         => array(
					'title'   => esc_html__( 'Gallery Thumbnail Size', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose a size for the contents of gallery.', 'pinkmart' ),
					'fields'  => array(
						'portfolio-featured-size' => $fields['portfolio-featured-size'],
					),
				), // Gallery Thumbnail Size
				'video'                 => array(
					'title'   => esc_html__( 'Video', 'pinkmart' ),
					'tooltip' => esc_html__( 'Copy and paste your browser URL in this section to automatically load a video into your gallery.', 'pinkmart' ),
					'fields'  => array(
						'video-type' => $fields['video-type'],
						'video-id'   => $fields['video-id'],
					),
				), // Video sec
				'audio'                 => array(
					'title'   => esc_html__( 'Post Audio', 'pinkmart' ),
					'tooltip' => esc_html__( 'You can enter audio URL hosted in SoundCloud', 'pinkmart' ),
					'fields'  => array(
						'audio-url' => $fields['audio-url'],
					),
				), // Audio sec
				'link'                  => array(
					'title'   => esc_html__( 'Post Link', 'pinkmart' ),
					'tooltip' => esc_html__( 'You can enter the URL of another website.', 'pinkmart' ),
					'fields'  => array(
						'link-url' => $fields['link-url'],
					),
				), // Audio sec
			);
	
			return array(
				array(
					'id'       => 'portfolio_meta_box',
					'title'    => esc_html__( 'Gallery Options', 'pinkmart' ),
					'context'  => 'normal',
					'priority' => 'default',
					'options'  => $options,
				), // Meta box
			);
		}
	}
	
	function kite_register_gallery_post_type() {
		Kite_Gallery::get_instance();
	}
	add_action( 'after_setup_theme', 'kite_register_gallery_post_type' );
}
