<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'Kite_Page' ) ) {
	class Kite_Page extends Kite_Post_Type {

		/**
		 * Instance of this class.
		 *
		 * @var      object
		 */
		protected static $instance = null;
	
		/**
		 * Return an instance of this class.
		 *
		 * @return    object    A single instance of this class.
		 */
		public static function get_instance() {
	
			// If the single instance hasn't been set, set it now.
			if ( null == self::$instance ) {
				self::$instance = new self;
			}
	
			return self::$instance;
		}
	
		function __construct() {
			parent::__construct( 'page' );
		}
	
		function kite_enqueue_scripts() {
			wp_enqueue_script( 'hoverIntent' );
			wp_enqueue_script( 'jquery-easing' );
	
			wp_enqueue_script( 'nouislider' );
			wp_enqueue_style( 'nouislider' );
	
			// Include wpcolorpicker + its patch to support alpha chanel
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker-alpha' );
	
			wp_enqueue_style( 'kite-admin-css' );
			wp_enqueue_script( 'kite-admin-js' );
	
			wp_enqueue_script( 'kite-page', KITE_THEME_LIB_URI . '/post-types/js/page.js', array( 'jquery' ), KITE_THEME_VERSION );
	
		}
	
		private function kite_get_sidebars() {
			$sidebars = array(
				'no-sidebar'   => esc_html__( 'No Sidebar', 'pinkmart' ),
				'page-sidebar' => esc_html__( 'Page Sidebar', 'pinkmart' ),
				'main-sidebar' => esc_html__( 'Blog Sidebar', 'pinkmart' ),
			);
	
			if ( kite_opt( 'custom_sidebars' ) != '' ) {
				$arr = explode( ',', kite_opt( 'custom_sidebars' ) );
	
				foreach ( $arr as $bar ) {
					$sidebars[ $bar ] = str_replace( '%666', ',', $bar );
				}
			}
	
			$sidebars = array_unique( $sidebars );
			return $sidebars;
		}
	
		protected function kite_get_options() {
	
			$args = array(
				'orderby'    => 'id',
				'order'      => 'DESC',
				'hide_empty' => false,
				'fields'     => 'all',
			);
	
			$fields = array(

				'is-header-build-with-elementor' => array(
					'type'    => 'switch',
					'label'   => esc_html__( 'Elementor Header Builder', 'pinkmart' ),
					'state0'  => esc_html__( 'Inherit from theme settings', 'pinkmart' ),
					'state1'  => esc_html__( 'custom', 'pinkmart' ),
					'value'   => 0,
					'default' => 0,
				),
				'header-template'       => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Choose your Header Template', 'pinkmart' ),
					'options' => kite_get_elementor_templates_list( 'header' ),
					'default' => '',
				),	
				'header-type-switch'       => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Choose your Header Type', 'pinkmart' ),
					'options' => array(
						'0' => esc_html__( 'Enable Header', 'pinkmart' ),
						'1' => esc_html__( 'Enable Top Space', 'pinkmart' ),
						'2' => esc_html__( 'Disable Top Space', 'pinkmart' ),
					),
					'default' => '0',
				),
				'header-title-bar-switch'  => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Section Title', 'pinkmart' ),
					'options' => array(
						'2' => esc_html__( 'Show post title', 'pinkmart' ),
						'1' => esc_html__( 'Show custom title', 'pinkmart' ),
						'0' => esc_html__( 'Don\'t show title', 'pinkmart' ),
					),
					'default' => '2',
				),
				'title-text'               => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Title Text', 'pinkmart' ),
					'placeholder' => esc_html__( 'Override title text', 'pinkmart' ),
	
				),
				'subtitle-text'            => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Subtitle Text', 'pinkmart' ),
					'placeholder' => esc_html__( 'Subtitle text', 'pinkmart' ),
				),
	
				'header-background-image'  => array(
					'type'  => 'upload',
					'label' => esc_html__( 'Background Image', 'pinkmart' ),
					'title' => esc_html__( 'Upload Background image for header', 'pinkmart' ),
				),
				'header-background-color'  => array(
					'type'  => 'color',
					'label' => esc_html__( 'Header Background Color', 'pinkmart' ),
					'value' => '',
				),
	
				'header-text-color'        => array(
					'type'  => 'color',
					'label' => esc_html__( 'Header Text Color', 'pinkmart' ),
					'value' => '',
				),
				'page-type-switch'         => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Section Type', 'pinkmart' ),
					'options' => array(
						'custom-section'  => esc_html__( 'Custom section', 'pinkmart' ),
						'blog-section'    => esc_html__( 'Blog section', 'pinkmart' ),
						'recently-viewed' => esc_html__( 'Recently Viewed Products', 'pinkmart' ),
					),
				),
				'page-position-switch'     => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Choose your section to be shown in:', 'pinkmart' ),
					'options' => array(
						'1' => esc_html__( 'OnePage Container', 'pinkmart' ),
						'0' => esc_html__( 'External page', 'pinkmart' ),
					),
				),
				'sidebar'                  => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Choose the sidebar', 'pinkmart' ),
					'options' => $this->kite_get_sidebars(),
				),
				'blog-sidebar'             => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Blog Sidebar Display', 'pinkmart' ),
					'options' => array(
						'0' => esc_html__( 'Inherit from theme settings', 'pinkmart' ),
						'1' => esc_html__( 'Show', 'pinkmart' ),
						'2' => esc_html__( 'Don\'t show', 'pinkmart' ),
					),
				),
				'blog-sidebar-position'    => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Blog Sidebar position', 'pinkmart' ),
					'options' => array(
						'main-sidebar' => esc_html__( 'Right sidebar', 'pinkmart' ),
						'left-sidebar' => esc_html__( 'Left Sidebar', 'pinkmart' ),
					),
				),
				'display-top-slider'       => array(
					'type'    => 'switch',
					'label'   => esc_html__( 'Top Slider', 'pinkmart' ),
					'state0'  => esc_html__( 'Disable', 'pinkmart' ),
					'state1'  => esc_html__( 'Enable', 'pinkmart' ),
					'value'   => 0,
					'default' => 0,
				),
				'revslider-container'      => array(
					'type'    => 'switch',
					'label'   => esc_html__( 'Revolution Slider Container/fullwidth', 'pinkmart' ),
					'state0'  => esc_html__( 'fullwidth', 'pinkmart' ),
					'state1'  => esc_html__( 'Container', 'pinkmart' ),
					'value'   => 0,
					'default' => 0,
				),
				'slider-parallax'          => array(
					'type'    => 'switch',
					'label'   => esc_html__( 'Slider parallax effect', 'pinkmart' ),
					'state0'  => esc_html__( 'Disable', 'pinkmart' ),
					'state1'  => esc_html__( 'Enable', 'pinkmart' ),
					'value'   => 1,
					'default' => 1,
				),
				'home-rev-slide'           => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Choose a revolution slider', 'pinkmart' ),
					'options' => kite_get_revolutionSlider_slides(),
				),
				'resume-exp-section'       => array(
					'type'    => 'checkbox',
					'checked' => true,
					'value'   => 'visible',
					'label'   => esc_html__( 'Experience', 'pinkmart' ),
				),
				'extra_class'              => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Extra Class Name', 'pinkmart' ),
					'placeholder' => esc_html__( 'class name ex: class1 class2', 'pinkmart' ),
				), // Extra class name
				'snap-to-scroll'           => array(
					'type'    => 'switch',
					'label'   => esc_html__( 'Enable snap to scroll', 'pinkmart' ),
					'state0'  => esc_html__( 'Disable', 'pinkmart' ),
					'state1'  => esc_html__( 'Enable', 'pinkmart' ),
					'default' => 0,
				),
				'snap-to-scroll-nav-style' => array(
					'type'    => 'switch',
					'label'   => esc_html__( 'Navigation style', 'pinkmart' ),
					'state0'  => esc_html__( 'Light', 'pinkmart' ),
					'state1'  => esc_html__( 'Dark', 'pinkmart' ),
					'default' => 0,
				),
				'is-footer-build-with-elementor' => array(
					'type'    => 'switch',
					'label'   => esc_html__( 'Elementor Footer Builder', 'pinkmart' ),
					'state0'  => esc_html__( 'Inherit from theme settings', 'pinkmart' ),
					'state1'  => esc_html__( 'custom', 'pinkmart' ),
					'value'   => 0,
					'default' => 0,
				),
				'footer-template'       => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Choose your Footer Template', 'pinkmart' ),
					'options' => kite_get_elementor_templates_list( 'footer' ),
					'default' => '',
				),
				'footer-widget-area'       => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Footer widget area visibility', 'pinkmart' ),
					'options' => array(
						'inherit' => 'Inherit from theme setting',
						'enable'  => 'Enable',
						'disable' => 'Disable',
					),
				),
				'page_bg_color'            => array(
					'type'  => 'color',
					'label' => esc_html__( 'page Background color', 'pinkmart' ),
					'title' => esc_html__( 'Upload Background image for page', 'pinkmart' ),
				),
				'page_bg_image'            => array(
					'type'  => 'upload',
					'label' => esc_html__( 'page Background Image', 'pinkmart' ),
					'title' => esc_html__( 'Upload Background image for page', 'pinkmart' ),
				),
				'bg_img_size'              => array(
					'type'    => 'select',
					'label'   => esc_html__( 'background image Size', 'pinkmart' ),
					'options' => array(
						'contain' => 'contain',
						'cover'   => 'cover',
						'initial' => 'initial',
					),
				),
				'bg_img_repeat'            => array(
					'type'    => 'select',
					'label'   => esc_html__( 'background image repeat', 'pinkmart' ),
					'options' => array(
						'repeat'    => 'repeat',
						'repeat-x'  => 'repeat-x',
						'repeat-y'  => 'repeat-y',
						'no-repeat' => 'no-repeat',
					),
				),
				'bg_img_position'          => array(
					'type'    => 'select',
					'label'   => esc_html__( 'background image position', 'pinkmart' ),
					'options' => array(
						'center'  => 'center',
						'top'     => 'top',
						'bottom'  => 'bottom',
						'right'   => 'right',
						'left'    => 'left',
						'inherit' => 'inherit',
					),
				),
				'bg_img_attachment'        => array(
					'type'    => 'select',
					'label'   => esc_html__( 'background image attachment:', 'pinkmart' ),
					'options' => array(
						'fixed'   => 'fixed',
						'scroll'  => 'scroll',
						'local'   => 'local',
						'inherit' => 'inherit',
						'unset'   => 'unset',
					),
				),
	
			);
	
			// merge fields array With portfolio Skill Arrays
			$fields = array_merge( $fields, Kite_generate_portfolio_skill() );
	
			// Option sections
			$options = array(
				'page-type-switch'      => array(
					'title'   => esc_html__( 'Section Type', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose a section which will be shown in OnePage Container page.   Create a new section. This section can be shown in any one of your pages.', 'pinkmart' ),
					'fields'  => array(
						'page-type-switch' => $fields['page-type-switch'],
					),
				), // Section Type
				'page-position-switch'  => array(
					'title'   => esc_html__( 'Section Display', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose where you want to show your section. It can be shown in OnePage Container page or be shown as an external page.', 'pinkmart' ),
					'fields'  => array(
						'page-position-switch' => $fields['page-position-switch'],
					),
				), // Open Page As Separate Page Or Front Page
				'page-sidebar'          => array(
					'title'   => esc_html__( 'Page Sidebar', 'pinkmart' ),
					'tooltip' => esc_html__( 'You can choose a sidebar to be shown in this section which is created in theme settings ', 'pinkmart' ),
					'fields'  => array(
						'sidebar' => $fields['sidebar'],
					),
				), // Add Page Sidebar
				'blog-sidebar'          => array(
					'title'   => esc_html__( 'Blog Sidebar', 'pinkmart' ),
					'tooltip' => esc_html__( 'You can enable or disable blog sidebar ', 'pinkmart' ),
					'fields'  => array(
						'blog-sidebar' => $fields['blog-sidebar'],
					),
				), // Enable blog Sidebar
				'blog-sidebar-position' => array(
					'title'   => esc_html__( 'Blog Sidebar Position', 'pinkmart' ),
					'tooltip' => esc_html__( 'choose left or right blog sidebar ', 'pinkmart' ),
					'fields'  => array(
						'blog-sidebar-position' => $fields['blog-sidebar-position'],
					),
				), // Enable blog Sidebar Position
				'is-footer-build-with-elementor'      => array(
					'title'   => esc_html__( 'Elementor Footer Builder', 'pinkmart' ),
					'tooltip' => esc_html__( 'Select to set custom footer for the page', 'pinkmart' ),
					'fields'  => array(
						'is-footer-build-with-elementor' => $fields['is-footer-build-with-elementor'],
					),
				),
				'footer-template'      => array(
					'title'   => esc_html__( 'Elementor Footer Template', 'pinkmart' ),
					'tooltip' => esc_html__( 'Select footer template that built with elementor', 'pinkmart' ),
					'fields'  => array(
						'footer-template' => $fields['footer-template'],
					),
				),	
				'footer-widget-area'    => array(
					'title'   => esc_html__( 'Footer Widget Area', 'pinkmart' ),
					'tooltip' => esc_html__( 'Enable or disable widget area in the footer.', 'pinkmart' ),
					'fields'  => array(
						'footer-widget-area' => $fields['footer-widget-area'],
					),
				), // Footer Widget Area
			// page background image
				'page_background_image' => array(
					'title'   => esc_html__( 'page background image', 'pinkmart' ),
					'tooltip' => esc_html__( 'choose image for page background.', 'pinkmart' ),
					'fields'  => array(
						'page_bg_color'     => $fields['page_bg_color'],
						'page_bg_image'     => $fields['page_bg_image'],
						'bg_img_size'       => $fields['bg_img_size'],
						'bg_img_repeat'     => $fields['bg_img_repeat'],
						'bg_img_position'   => $fields['bg_img_position'],
						'bg_img_attachment' => $fields['bg_img_attachment'],
	
					),
				),
				'extra_class'           => array(
					'title'   => esc_html__( 'Extra Class name', 'pinkmart' ),
					'tooltip' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS. use space between diffrent class name', 'pinkmart' ),
					'fields'  => array(
						'extra_class' => $fields['extra_class'],
					),
				), // Extra Class name
			);
			$headerOptions = array(
				'is-header-build-with-elementor'      => array(
					'title'   => esc_html__( 'Elementor Header Builder', 'pinkmart' ),
					'tooltip' => esc_html__( 'Select to set custom header for this page', 'pinkmart' ),
					'fields'  => array(
						'is-header-build-with-elementor' => $fields['is-header-build-with-elementor'],
					),
				),
				'header-template'      => array(
					'title'   => esc_html__( 'Header Template', 'pinkmart' ),
					'tooltip' => esc_html__( 'Select header template that built with elementor', 'pinkmart' ),
					'fields'  => array(
						'header-template' => $fields['header-template'],
					),
				),	
				'header-type-switch'      => array(
					'title'   => esc_html__( 'Header Type', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose your Header Type that you want to show in your page.', 'pinkmart' ),
					'fields'  => array(
						'header-type-switch' => $fields['header-type-switch'],
					),
				), // header type
				'title-bar'               => array(
					'title'   => esc_html__( 'Title', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose a title to be shown at the beginning of each section', 'pinkmart' ),
					'fields'  => array(
						'title-bar'     => $fields['header-title-bar-switch'],
						'title-text'    => $fields['title-text'],
						'subtitle-text' => $fields['subtitle-text'],
					),
				), // Title bar sec
				'header-background-image' => array(
					'title'   => esc_html__( 'Header Background Image', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose your Header background image that you want to show in your page.', 'pinkmart' ),
					'fields'  => array(
						'header-background-image' => $fields['header-background-image'],
					),
				), // header Background image
				'header-background-color' => array(
					'title'   => esc_html__( 'Header Background Color', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose Header Background Color that you want to show in Header of Page.', 'pinkmart' ),
					'fields'  => array(
						'header-background-color' => $fields['header-background-color'],
					),
				), // header background color
				'header-text-color'       => array(
					'title'   => esc_html__( 'Header Text Color', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose Header Text Color that you want to show in Header of Page.', 'pinkmart' ),
					'fields'  => array(
						'header-text-color' => $fields['header-text-color'],
					),
				), // header Text color
	
			);
	
			$sliderOptions = array(
				'display-top-slider'     => array(
					'title'   => esc_html__( 'Slider Visibility', 'pinkmart' ),
					'tooltip' => esc_html__( 'Enable or disable Slider.', 'pinkmart' ),
					'fields'  => array(
						'display-top-slider' => $fields['display-top-slider'],
					),
				), // Display Header
				'revslider-container'    => array(
					'title'   => esc_html__( 'Slider Revolution Type', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose your slider type.', 'pinkmart' ),
					'fields'  => array(
						'revslider-container' => $fields['revslider-container'],
					),
				), // Intro Full-width Slider
				'slider-parallax'        => array(
					'title'   => esc_html__( 'Slider parallax effect', 'pinkmart' ),
					'tooltip' => esc_html__( 'Enable or disable parallax effect of slider.', 'pinkmart' ),
					'fields'  => array(
						'slider-parallax' => $fields['slider-parallax'],
					),
				),
				'slide-revolutionSlider' => array(
					'title'   => esc_html__( 'Revolution Slider', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose an existing revolution slider slide show, to be shown in intro section', 'pinkmart' ),
					'fields'  => array(
						'home-rev-slide' => $fields['home-rev-slide'],
					),
				),
	
			);
	
			$SnapToScrollOptions = array(
				'snap-to-scroll'           => array(
					'title'   => esc_html__( 'Snap to Scroll', 'pinkmart' ),
					'tooltip' => esc_html__( 'Enable or disable snap to scroll for this page.', 'pinkmart' ),
					'fields'  => array(
						'snap-to-scroll' => $fields['snap-to-scroll'],
					),
				), // Display Header
				'snap-to-scroll-nav-style' => array(
					'title'   => esc_html__( 'Navigation style', 'pinkmart' ),
					'tooltip' => esc_html__( 'Navigation style(Dark/Light)', 'pinkmart' ),
					'fields'  => array(
						'snap-to-scroll-nav-style' => $fields['snap-to-scroll-nav-style'],
					),
				),
			);
	
			$menuOptions = array(
				'menu'               => array(
					'title'   => esc_html__( 'Menu style', 'pinkmart' ),
					'tooltip' => esc_html__( 'Override menu style for current page.', 'pinkmart' ),
					'fields'  => array(
						'menu' => array(
							'type'    => 'select',
							'label'   => esc_html__( 'Menu style', 'pinkmart' ),
							'options' => array(
								'default' => esc_html__( 'Inherit from theme settings', 'pinkmart' ),
								'custom'  => esc_html__( 'Custom', 'pinkmart' ),
							),
						),
					),
				),
				'initial-menu-color' => array(
					'title'   => esc_html__( 'Initial Menu Colors', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose the color and set the opacity for initial menu.', 'pinkmart' ),
					'fields'  => array(
						'initial-menu-background-color'    => array(
							'type'  => 'color',
							'label' => esc_html__( 'Background Color', 'pinkmart' ),
							'value' => '#ffffff',
						),
						'initial-menu-text-color'          => array(
							'type'  => 'color',
							'label' => esc_html__( 'Text Color', 'pinkmart' ),
							'value' => '#000000',
						),
						'initial-menu-text-hover-color'    => array(
							'type'  => 'color',
							'label' => esc_html__( 'Text Hover Color', 'pinkmart' ),
							'value' => '#000000',
							'class' => 'menu-hover-color',
						),
						'initial-menu-text-bg-hover-color' => array(
							'type'  => 'color',
							'label' => esc_html__( 'on-hover Background Color', 'pinkmart' ),
							'value' => '#f83333',
							'class' => 'menu-bg-hover-color',
						),
						'initial-menu-border-color'        => array(
							'type'  => 'color',
							'class' => 'initial-border-color',
							'label' => esc_html__( 'Border Color', 'pinkmart' ),
							'value' => '#eee',
						),
					),
				),
				'menu-color'         => array(
					'title'   => esc_html__( 'Menu Colors', 'pinkmart' ),
					'tooltip' => esc_html__( 'Choose the color and set the opacity for menu.', 'pinkmart' ),
					'fields'  => array(
						'menu-background-color'    => array(
							'type'  => 'color',
							'label' => esc_html__( 'Background Color', 'pinkmart' ),
							'value' => '#ffffff',
						),
						'menu-text-color'          => array(
							'type'  => 'color',
							'label' => esc_html__( 'Text Color', 'pinkmart' ),
							'value' => '#000000',
						),
						'menu-text-hover-color'    => array(
							'type'  => 'color',
							'label' => esc_html__( 'Text Hover Color', 'pinkmart' ),
							'value' => '#000000',
							'class' => 'menu-hover-color',
						),
						'menu-text-bg-hover-color' => array(
							'type'  => 'color',
							'label' => esc_html__( 'on-hover Background Color', 'pinkmart' ),
							'value' => '#e8e8e8',
							'class' => 'menu-bg-hover-color',
						),
						'menu-border-color'        => array(
							'type'  => 'color',
							'class' => 'border-color',
							'label' => esc_html__( 'Border Color', 'pinkmart' ),
							'value' => '#eee',
						),
					),
				),
			);
	
			$metaboxes = array(
				array(
					'id'       => 'page_header_meta_box',
					'title'    => esc_html__( 'Page Header Settings', 'pinkmart' ),
					'context'  => 'normal',
					'priority' => 'high',
					'options'  => $headerOptions,
				), // Meta box 1
				array(
					'id'       => 'snap_to_scroll_meta_box',
					'title'    => esc_html__( 'Snap to Scroll Settings', 'pinkmart' ),
					'context'  => 'normal',
					'priority' => 'high',
					'options'  => $SnapToScrollOptions,
				), // Meta box 2
				array(
					'id'       => 'blog_meta_box',
					'title'    => esc_html__( 'Page Settings', 'pinkmart' ),
					'context'  => 'normal',
					'priority' => 'high',
					'options'  => $options,
				), // Meta box 3
				array(
					'id'       => 'slider_meta_box',
					'title'    => esc_html__( 'Top Slider Settings', 'pinkmart' ),
					'context'  => 'normal',
					'priority' => 'high',
					'options'  => $sliderOptions,
				), // Meta box 4
			);
	
			// Add menu metabox - unset some options that is not appropriate for current menu type
			if ( kite_opt( 'header-type' ) != 7 && kite_opt( 'header-type' ) != 8 ) {
	
				if ( kite_opt( 'menu-hover-style' ) == 3 ) {
					unset( $menuOptions['menu-color']['fields']['menu-text-hover-color'] );
					unset( $menuOptions['initial-menu-color']['fields']['initial-menu-text-hover-color'] );
	
					unset( $menuOptions['menu-color']['fields']['menu-text-bg-hover-color'] );
					unset( $menuOptions['initial-menu-color']['fields']['initial-menu-text-bg-hover-color'] );
				} elseif ( kite_opt( 'menu-hover-style' ) == 2 ) {
					unset( $menuOptions['menu-color']['fields']['menu-text-bg-hover-color'] );
					unset( $menuOptions['initial-menu-color']['fields']['initial-menu-text-bg-hover-color'] );
				}
	
				if ( kite_opt( 'header-style' ) == 'fixed-menu' ) {
					unset( $menuOptions['menu-color'] );
				}
	
				$metaboxes[] = array(
					'id'       => 'menu_meta_box',
					'title'    => esc_html__( 'Menu Settings', 'pinkmart' ),
					'context'  => 'normal',
					'priority' => 'high',
					'options'  => $menuOptions,
				);
			}
	
			return $metaboxes;
	
		}
	}
	
	Kite_Page::get_instance();
}
